summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authoredward <edward@4angle.com>2017-02-09 08:18:56 +0000
committeredward <edward@4angle.com>2017-02-09 08:18:56 +0000
commitbdfd0d6bb7c0f2751676ff7ed30fcd8d69f9a61e (patch)
treef7b0d9265f84cc19aaad46f0c03a794b5414e8d7
parent95071a0d8a92c1ed482bdf06bbde92cdd9967c09 (diff)
downloadruamel.yaml-bdfd0d6bb7c0f2751676ff7ed30fcd8d69f9a61e.tar.gz
fix spelling mistakes
-rw-r--r--composer.py6
-rw-r--r--ext/_ruamel_yaml.c60
-rw-r--r--ext/_ruamel_yaml.pyx8
-rw-r--r--ext/loader.c4
-rw-r--r--ext/scanner.c2
5 files changed, 40 insertions, 40 deletions
diff --git a/ext/_ruamel_yaml.pyx b/ext/_ruamel_yaml.pyx
index 55c1e39..cf0204a 100644
--- a/ext/_ruamel_yaml.pyx
+++ b/ext/_ruamel_yaml.pyx
@@ -761,11 +761,11 @@ cdef class CParser:
self.parsed_event.start_mark.column,
None, None)
if PY_MAJOR_VERSION < 3:
- raise ComposerError("found duplicate anchor; first occurence",
- self.anchors[anchor].start_mark, "second occurence", mark)
+ raise ComposerError("found duplicate anchor; first occurrence",
+ self.anchors[anchor].start_mark, "second occurrence", mark)
else:
- raise ComposerError(u"found duplicate anchor; first occurence",
- self.anchors[anchor].start_mark, u"second occurence", mark)
+ raise ComposerError(u"found duplicate anchor; first occurrence",
+ self.anchors[anchor].start_mark, u"second occurrence", mark)
self.descend_resolver(parent, index)
if self.parsed_event.type == YAML_SCALAR_EVENT:
node = self._compose_scalar_node(anchor)
diff --git a/ext/loader.c b/ext/loader.c
index 871149a..3ba99f0 100644
--- a/ext/loader.c
+++ b/ext/loader.c
@@ -239,8 +239,8 @@ yaml_parser_register_anchor(yaml_parser_t *parser,
if (strcmp((char *)alias_data->anchor, (char *)anchor) == 0) {
yaml_free(anchor);
return yaml_parser_set_composer_error_context(parser,
- "found duplicate anchor; first occurence",
- alias_data->mark, "second occurence", data.mark);
+ "found duplicate anchor; first occurrence",
+ alias_data->mark, "second occurrence", data.mark);
}
}
diff --git a/ext/scanner.c b/ext/scanner.c
index 8817de2..a5d69c0 100644
--- a/ext/scanner.c
+++ b/ext/scanner.c
@@ -2060,7 +2060,7 @@ yaml_parser_scan_directive(yaml_parser_t *parser, yaml_token_t *token)
else
{
yaml_parser_set_scanner_error(parser, "while scanning a directive",
- start_mark, "found uknown directive name");
+ start_mark, "found unknown directive name");
goto error;
}
diff --git a/composer.py b/composer.py
index 791bf50..1907abc 100644
--- a/composer.py
+++ b/composer.py
@@ -89,10 +89,10 @@ class Composer(object):
if anchor is not None: # have an anchor
if anchor in self.anchors:
# raise ComposerError(
# "found duplicate anchor %r; first occurence"
# % utf8(anchor), self.anchors[anchor].start_mark,
- # "second occurence", event.start_mark)
- ws = "\nfound duplicate anchor {!r}\nfirst occurence {}\nsecond occurence "\
+ # "second occurrence", event.start_mark)
+ ws = "\nfound duplicate anchor {!r}\nfirst occurrence {}\nsecond occurrence "\
"{}".format(
(anchor), self.anchors[anchor].start_mark, event.start_mark)
warnings.warn(ws, ReusedAnchorWarning)
@@ -89,10 +89,10 @@ class Composer(object):
if anchor in self.anchors:
# raise ComposerError(
- # "found duplicate anchor %r; first occurence"
+ # "found duplicate anchor %r; first occurrence"
# % utf8(anchor), self.anchors[anchor].start_mark,
diff --git a/ext/_ruamel_yaml.c b/ext/_ruamel_yaml.c
index 1a5252a..1f4b938 100644
--- a/ext/_ruamel_yaml.c
+++ b/ext/_ruamel_yaml.c
@@ -932,7 +932,7 @@ static char __pyx_k_StreamStartEvent[] = "StreamStartEvent";
static char __pyx_k_StreamStartToken[] = "StreamStartToken";
static char __pyx_k_descend_resolver[] = "descend_resolver";
static char __pyx_k_no_emitter_error[] = "no emitter error";
-static char __pyx_k_second_occurence[] = "second occurence";
+static char __pyx_k_second_occurrence[] = "second occurrence";
static char __pyx_k_MappingStartEvent[] = "MappingStartEvent";
static char __pyx_k_ruamel_yaml_error[] = "ruamel.yaml.error";
static char __pyx_k_ruamel_yaml_nodes[] = "ruamel.yaml.nodes";
@@ -973,7 +973,7 @@ static char __pyx_k_serializer_is_already_opened[] = "serializer is already open
static char __pyx_k_home_avdndata_hg_ruamel_eu_src[] = "/home/avdndata/hg/ruamel.eu/src/site-packages/ruamel/yaml/ext/_ruamel_yaml.pyx";
static char __pyx_k_a_string_or_stream_input_is_requ[] = "a string or stream input is required";
static char __pyx_k_expected_a_single_document_in_th[] = "expected a single document in the stream";
-static char __pyx_k_found_duplicate_anchor_first_occ[] = "found duplicate anchor; first occurence";
+static char __pyx_k_found_duplicate_anchor_first_occ[] = "found duplicate anchor; first occurrence";
static PyObject *__pyx_n_s_AliasEvent;
static PyObject *__pyx_n_s_AliasToken;
static PyObject *__pyx_n_s_AnchorToken;
@@ -1108,8 +1108,8 @@ static PyObject *__pyx_n_s_ruamel_yaml_representer;
static PyObject *__pyx_n_s_ruamel_yaml_scanner;
static PyObject *__pyx_n_s_ruamel_yaml_serializer;
static PyObject *__pyx_n_s_ruamel_yaml_tokens;
-static PyObject *__pyx_kp_s_second_occurence;
-static PyObject *__pyx_kp_u_second_occurence;
+static PyObject *__pyx_kp_s_second_occurrence;
+static PyObject *__pyx_kp_u_second_occurrence;
static PyObject *__pyx_kp_s_serializer_is_already_opened;
static PyObject *__pyx_kp_u_serializer_is_already_opened;
static PyObject *__pyx_kp_s_serializer_is_closed;
@@ -10543,8 +10543,8 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
* self.parsed_event.start_mark.column,
* None, None)
* if PY_MAJOR_VERSION < 3: # <<<<<<<<<<<<<<
* raise ComposerError("found duplicate anchor; first occurence",
* self.anchors[anchor].start_mark, "second occurence", mark)
*/
__pyx_t_4 = ((PY_MAJOR_VERSION < 3) != 0);
if (__pyx_t_4) {
@@ -10552,8 +10552,8 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
/* "_ruamel_yaml.pyx":764
* None, None)
* if PY_MAJOR_VERSION < 3:
* raise ComposerError("found duplicate anchor; first occurence", # <<<<<<<<<<<<<<
* self.anchors[anchor].start_mark, "second occurence", mark)
* else:
*/
__pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ComposerError); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 764; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
@@ -10561,10 +10561,10 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
/* "_ruamel_yaml.pyx":765
* if PY_MAJOR_VERSION < 3:
* raise ComposerError("found duplicate anchor; first occurence",
* self.anchors[anchor].start_mark, "second occurence", mark) # <<<<<<<<<<<<<<
* else:
* raise ComposerError(u"found duplicate anchor; first occurence",
*/
__pyx_t_7 = PyObject_GetItem(__pyx_v_self->anchors, __pyx_v_anchor); if (unlikely(__pyx_t_7 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 765; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
__Pyx_GOTREF(__pyx_t_7);
@@ -10593,9 +10593,9 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_kp_s_found_duplicate_anchor_first_occ);
__Pyx_GIVEREF(__pyx_t_6);
PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_6);
- __Pyx_INCREF(__pyx_kp_s_second_occurence);
- __Pyx_GIVEREF(__pyx_kp_s_second_occurence);
- PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_8, __pyx_kp_s_second_occurence);
+ __Pyx_INCREF(__pyx_kp_s_second_occurrence);
+ __Pyx_GIVEREF(__pyx_kp_s_second_occurrence);
+ PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_8, __pyx_kp_s_second_occurrence);
__Pyx_INCREF(((PyObject *)__pyx_v_mark));
__Pyx_GIVEREF(((PyObject *)__pyx_v_mark));
PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_8, ((PyObject *)__pyx_v_mark));
@@ -10612,16 +10612,16 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
* self.parsed_event.start_mark.column,
* None, None)
* if PY_MAJOR_VERSION < 3: # <<<<<<<<<<<<<<
* raise ComposerError("found duplicate anchor; first occurence",
* self.anchors[anchor].start_mark, "second occurence", mark)
*/
}
/* "_ruamel_yaml.pyx":767
- * self.anchors[anchor].start_mark, "second occurence", mark)
+ * self.anchors[anchor].start_mark, "second occurrence", mark)
* else:
* raise ComposerError(u"found duplicate anchor; first occurence", # <<<<<<<<<<<<<<
* self.anchors[anchor].start_mark, u"second occurence", mark)
* self.descend_resolver(parent, index)
*/
/*else*/ {
@@ -10630,8 +10630,8 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
/* "_ruamel_yaml.pyx":768
* else:
* raise ComposerError(u"found duplicate anchor; first occurence",
* self.anchors[anchor].start_mark, u"second occurence", mark) # <<<<<<<<<<<<<<
* self.descend_resolver(parent, index)
* if self.parsed_event.type == YAML_SCALAR_EVENT:
*/
@@ -10662,9 +10662,9 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_8, __pyx_kp_u_found_duplicate_anchor_first_occ);
__Pyx_GIVEREF(__pyx_t_6);
PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_8, __pyx_t_6);
- __Pyx_INCREF(__pyx_kp_u_second_occurence);
- __Pyx_GIVEREF(__pyx_kp_u_second_occurence);
- PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_8, __pyx_kp_u_second_occurence);
+ __Pyx_INCREF(__pyx_kp_u_second_occurrence);
+ __Pyx_GIVEREF(__pyx_kp_u_second_occurrence);
+ PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_8, __pyx_kp_u_second_occurrence);
__Pyx_INCREF(((PyObject *)__pyx_v_mark));
__Pyx_GIVEREF(((PyObject *)__pyx_v_mark));
PyTuple_SET_ITEM(__pyx_t_7, 3+__pyx_t_8, ((PyObject *)__pyx_v_mark));
@@ -10697,8 +10697,8 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
}
/* "_ruamel_yaml.pyx":769
* raise ComposerError(u"found duplicate anchor; first occurence",
* self.anchors[anchor].start_mark, u"second occurence", mark)
* self.descend_resolver(parent, index) # <<<<<<<<<<<<<<
* if self.parsed_event.type == YAML_SCALAR_EVENT:
* node = self._compose_scalar_node(anchor)
@@ -10735,7 +10735,7 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
__Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
/* "_ruamel_yaml.pyx":770
- * self.anchors[anchor].start_mark, u"second occurence", mark)
+ * self.anchors[anchor].start_mark, u"second occurrence", mark)
* self.descend_resolver(parent, index)
* if self.parsed_event.type == YAML_SCALAR_EVENT: # <<<<<<<<<<<<<<
* node = self._compose_scalar_node(anchor)
@@ -10757,7 +10757,7 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
__pyx_t_5 = 0;
/* "_ruamel_yaml.pyx":770
- * self.anchors[anchor].start_mark, u"second occurence", mark)
+ * self.anchors[anchor].start_mark, u"second occurrence", mark)
* self.descend_resolver(parent, index)
* if self.parsed_event.type == YAML_SCALAR_EVENT: # <<<<<<<<<<<<<<
* node = self._compose_scalar_node(anchor)
@@ -22237,8 +22237,8 @@ static __Pyx_StringTabEntry __pyx_string_tab[] = {
{&__pyx_n_s_ruamel_yaml_scanner, __pyx_k_ruamel_yaml_scanner, sizeof(__pyx_k_ruamel_yaml_scanner), 0, 0, 1, 1},
{&__pyx_n_s_ruamel_yaml_serializer, __pyx_k_ruamel_yaml_serializer, sizeof(__pyx_k_ruamel_yaml_serializer), 0, 0, 1, 1},
{&__pyx_n_s_ruamel_yaml_tokens, __pyx_k_ruamel_yaml_tokens, sizeof(__pyx_k_ruamel_yaml_tokens), 0, 0, 1, 1},
- {&__pyx_kp_s_second_occurence, __pyx_k_second_occurence, sizeof(__pyx_k_second_occurence), 0, 0, 1, 0},
- {&__pyx_kp_u_second_occurence, __pyx_k_second_occurence, sizeof(__pyx_k_second_occurence), 0, 1, 0, 0},
+ {&__pyx_kp_s_second_occurrence, __pyx_k_second_occurrence, sizeof(__pyx_k_second_occurrence), 0, 0, 1, 0},
+ {&__pyx_kp_u_second_occurrence, __pyx_k_second_occurrence, sizeof(__pyx_k_second_occurrence), 0, 1, 0, 0},
{&__pyx_kp_s_serializer_is_already_opened, __pyx_k_serializer_is_already_opened, sizeof(__pyx_k_serializer_is_already_opened), 0, 0, 1, 0},
{&__pyx_kp_u_serializer_is_already_opened, __pyx_k_serializer_is_already_opened, sizeof(__pyx_k_serializer_is_already_opened), 0, 1, 0, 0},
{&__pyx_kp_s_serializer_is_closed, __pyx_k_serializer_is_closed, sizeof(__pyx_k_serializer_is_closed), 0, 0, 1, 0},
@@ -10543,8 +10543,8 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
* None, None)
* if PY_MAJOR_VERSION < 3: # <<<<<<<<<<<<<<
- * raise ComposerError("found duplicate anchor; first occurence",
- * self.anchors[anchor].start_mark, "second occurence", mark)
+ * raise ComposerError("found duplicate anchor; first occurrence",
+ * self.anchors[anchor].start_mark, "second occurrence", mark)
*/
__pyx_t_4 = ((PY_MAJOR_VERSION < 3) != 0);
@@ -10552,8 +10552,8 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
* None, None)
* if PY_MAJOR_VERSION < 3:
- * raise ComposerError("found duplicate anchor; first occurence", # <<<<<<<<<<<<<<
- * self.anchors[anchor].start_mark, "second occurence", mark)
+ * raise ComposerError("found duplicate anchor; first occurrence", # <<<<<<<<<<<<<<
+ * self.anchors[anchor].start_mark, "second occurrence", mark)
* else:
*/
@@ -10561,10 +10561,10 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
/* "_ruamel_yaml.pyx":765
* if PY_MAJOR_VERSION < 3:
- * raise ComposerError("found duplicate anchor; first occurence",
- * self.anchors[anchor].start_mark, "second occurence", mark) # <<<<<<<<<<<<<<
+ * raise ComposerError("found duplicate anchor; first occurrence",
+ * self.anchors[anchor].start_mark, "second occurrence", mark) # <<<<<<<<<<<<<<
* else:
@@ -10561,10 +10561,10 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
* else:
- * raise ComposerError(u"found duplicate anchor; first occurence",
+ * raise ComposerError(u"found duplicate anchor; first occurrence",
*/
__pyx_t_7 = PyObject_GetItem(__pyx_v_self->anchors, __pyx_v_anchor); if (unlikely(__pyx_t_7 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 765; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
@@ -10612,16 +10612,16 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
* None, None)
* if PY_MAJOR_VERSION < 3: # <<<<<<<<<<<<<<
- * raise ComposerError("found duplicate anchor; first occurence",
- * self.anchors[anchor].start_mark, "second occurence", mark)
+ * raise ComposerError("found duplicate anchor; first occurrence",
+ * self.anchors[anchor].start_mark, "second occurrence", mark)
*/
}
@@ -10612,16 +10612,16 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
* else:
- * raise ComposerError(u"found duplicate anchor; first occurence", # <<<<<<<<<<<<<<
- * self.anchors[anchor].start_mark, u"second occurence", mark)
+ * raise ComposerError(u"found duplicate anchor; first occurrence", # <<<<<<<<<<<<<<
+ * self.anchors[anchor].start_mark, u"second occurrence", mark)
* self.descend_resolver(parent, index)
*/
@@ -10630,8 +10630,8 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
/* "_ruamel_yaml.pyx":768
* else:
- * raise ComposerError(u"found duplicate anchor; first occurence",
- * self.anchors[anchor].start_mark, u"second occurence", mark) # <<<<<<<<<<<<<<
+ * raise ComposerError(u"found duplicate anchor; first occurrence",
+ * self.anchors[anchor].start_mark, u"second occurrence", mark) # <<<<<<<<<<<<<<
* self.descend_resolver(parent, index)
* if self.parsed_event.type == YAML_SCALAR_EVENT:
@@ -10697,8 +10697,8 @@ static PyObject *__pyx_f_12_ruamel_yaml_7CParser__compose_node(struct __pyx_obj_
}
/* "_ruamel_yaml.pyx":769
- * raise ComposerError(u"found duplicate anchor; first occurence",
- * self.anchors[anchor].start_mark, u"second occurence", mark)
+ * raise ComposerError(u"found duplicate anchor; first occurrence",
+ * self.anchors[anchor].start_mark, u"second occurrence", mark)
* self.descend_resolver(parent, index) # <<<<<<<<<<<<<<
* if self.parsed_event.type == YAML_SCALAR_EVENT: